diff --git a/lib/request-config.c b/lib/request-config.c
index abcca58..d9ecc8e 100644
--- a/lib/request-config.c
+++ b/lib/request-config.c
@@ -13,7 +13,7 @@
 struct gpiod_request_config {
 	char consumer[GPIO_MAX_NAME_SIZE];
 	unsigned int offsets[GPIO_V2_LINES_MAX];
-	size_t num_offsets;
+	size_t num_lines;
 	size_t event_buffer_size;
 };
 
@@ -54,22 +54,22 @@ gpiod_request_config_get_consumer(struct gpiod_request_config *config)
 
 GPIOD_API void
 gpiod_request_config_set_offsets(struct gpiod_request_config *config,
-				 size_t num_offsets,
+				 size_t num_lines,
 				 const unsigned int *offsets)
 {
 	size_t i;
 
-	config->num_offsets = num_offsets > GPIO_V2_LINES_MAX ?
-					GPIO_V2_LINES_MAX : num_offsets;
+	config->num_lines = num_lines > GPIO_V2_LINES_MAX ?
+					GPIO_V2_LINES_MAX : num_lines;
 
-	for (i = 0; i < config->num_offsets; i++)
+	for (i = 0; i < config->num_lines; i++)
 		config->offsets[i] = offsets[i];
 }
 
 GPIOD_API size_t
-gpiod_request_config_get_num_offsets(struct gpiod_request_config *config)
+gpiod_request_config_get_num_lines(struct gpiod_request_config *config)
 {
-	return config->num_offsets;
+	return config->num_lines;
 }
 
 GPIOD_API void
@@ -77,7 +77,7 @@ gpiod_request_config_get_offsets(struct gpiod_request_config *config,
 				 unsigned int *offsets)
 {
 	memcpy(offsets, config->offsets,
-	       sizeof(*offsets) * config->num_offsets);
+	       sizeof(*offsets) * config->num_lines);
 }
 
 GPIOD_API void
@@ -98,15 +98,15 @@ int gpiod_request_config_to_kernel(struct gpiod_request_config *config,
 {
 	size_t i;
 
-	if (config->num_offsets == 0) {
+	if (config->num_lines == 0) {
 		errno = EINVAL;
 		return -1;
 	}
 
-	for (i = 0; i < config->num_offsets; i++)
+	for (i = 0; i < config->num_lines; i++)
 		reqbuf->offsets[i] = config->offsets[i];
 
-	reqbuf->num_lines = config->num_offsets;
+	reqbuf->num_lines = config->num_lines;
 	strcpy(reqbuf->consumer, config->consumer);
 	reqbuf->event_buffer_size = config->event_buffer_size;
 
diff --git a/tests/tests-line-request.c b/tests/tests-line-request.c
index 8ef391d..eb3adee 100644
--- a/tests/tests-line-request.c
+++ b/tests/tests-line-request.c
@@ -21,7 +21,7 @@ GPIOD_TEST_CASE(request_fails_with_no_offsets)
 	req_cfg = gpiod_test_create_request_config_or_fail();
 	line_cfg = gpiod_test_create_line_config_or_fail();
 
-	g_assert_cmpuint(gpiod_request_config_get_num_offsets(req_cfg), ==, 0);
+	g_assert_cmpuint(gpiod_request_config_get_num_lines(req_cfg), ==, 0);
 	chip = gpiod_test_open_chip_or_fail(g_gpiosim_chip_get_dev_path(sim));
 
 	request = gpiod_chip_request_lines(chip, req_cfg, line_cfg);
diff --git a/tests/tests-request-config.c b/tests/tests-request-config.c
index becb414..136fe07 100644
--- a/tests/tests-request-config.c
+++ b/tests/tests-request-config.c
@@ -16,7 +16,7 @@ GPIOD_TEST_CASE(default_config)
 	config = gpiod_test_create_request_config_or_fail();
 
 	g_assert_null(gpiod_request_config_get_consumer(config));
-	g_assert_cmpuint(gpiod_request_config_get_num_offsets(config), ==, 0);
+	g_assert_cmpuint(gpiod_request_config_get_num_lines(config), ==, 0);
 	g_assert_cmpuint(gpiod_request_config_get_event_buffer_size(config),
 			 ==, 0);
 }
@@ -42,7 +42,7 @@ GPIOD_TEST_CASE(offsets)
 	config = gpiod_test_create_request_config_or_fail();
 
 	gpiod_request_config_set_offsets(config, 4, offsets);
-	g_assert_cmpuint(gpiod_request_config_get_num_offsets(config), ==, 4);
+	g_assert_cmpuint(gpiod_request_config_get_num_lines(config), ==, 4);
 	memset(read_back, 0, sizeof(read_back));
 	gpiod_request_config_get_offsets(config, read_back);
 	for (i = 0; i < 4; i++)
@@ -71,11 +71,11 @@ GPIOD_TEST_CASE(max_offsets)
 	config = gpiod_test_create_request_config_or_fail();
 
 	gpiod_request_config_set_offsets(config, 64, offsets_good);
-	g_assert_cmpuint(gpiod_request_config_get_num_offsets(config), ==, 64);
+	g_assert_cmpuint(gpiod_request_config_get_num_lines(config), ==, 64);
 
 	gpiod_request_config_set_offsets(config, 65, offsets_bad);
 	/* Should get truncated. */
-	g_assert_cmpuint(gpiod_request_config_get_num_offsets(config), ==, 64);
+	g_assert_cmpuint(gpiod_request_config_get_num_lines(config), ==, 64);
 }
 
 GPIOD_TEST_CASE(event_buffer_size)

diff --git a/include/gpiod.h b/include/gpiod.h
index e6a4645..8fb70ee 100644
--- a/include/gpiod.h
+++ b/include/gpiod.h
@@ -1094,12 +1094,12 @@ void gpiod_request_config_set_offsets(struct gpiod_request_config *config,
 				      const unsigned int *offsets);
 
 /**
  * @brief Get the number of offsets configured in this request config.
  * @param config Request config object.
- * @return Number of line offsets in this request config.
+ * @return Number of lines to be requested by this config.
  */
 size_t
-gpiod_request_config_get_num_offsets(struct gpiod_request_config *config);
+gpiod_request_config_get_num_lines(struct gpiod_request_config *config);
 
 /**
  * @brief Get the hardware offsets of lines in this request config.
@@ -1094,12 +1094,12 @@ void gpiod_request_config_set_offsets(struct gpiod_request_config *config,
 
 /**
- * @brief Get the number of offsets configured in this request config.
+ * @brief Get the number of lines configured in this request config.
  * @param config Request config object.